package org.jvnet.hifaces.components.templatedpanel.impl;

import javax.faces.context.FacesContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jvnet.hifaces.components.templatedpanel.Constants;

public class DefaultTemplateNameResolverFactory implements
		TemplateNameResolverFactory {

	private TemplateNameResolver templateNameResolver;

	public TemplateNameResolver getTemplateNameResolver(FacesContext context) {
		if (templateNameResolver == null) {
			templateNameResolver = createTemplateNameResolver();
		}
		return templateNameResolver;
	}

	private TemplateNameResolver createTemplateNameResolver() {
		return new URLTemplateNameResolver();
	}

	private static Log logger = LogFactory
			.getLog(TemplateNameResolverFactory.class);

	private static TemplateNameResolverFactory templateNameResolverFactory;

	public static TemplateNameResolverFactory getInstance(FacesContext context) {
		if (templateNameResolverFactory == null) {
			templateNameResolverFactory = createTemplateNameResolverFactory(context);
		}
		return templateNameResolverFactory;
	}

	private static TemplateNameResolverFactory createTemplateNameResolverFactory(
			FacesContext context) {
		final String templateNameResolverFactoryClassName = context == null ? null
				: context
						.getExternalContext()
						.getInitParameter(
								Constants.TEMPLATE_NAME_RESOLVER_FACTORY_CLASS_INIT_PARAMETER_NAME);

		if (templateNameResolverFactoryClassName == null) {
			return createDefaultTemplateNameResolverFactory();
		} else {
			try {
				final Class templateNameResolverFactoryClass = Class
						.forName(templateNameResolverFactoryClassName);
				final TemplateNameResolverFactory templateNameResolverFactory = (TemplateNameResolverFactory) templateNameResolverFactoryClass
						.newInstance();
				return templateNameResolverFactory;

			} catch (Exception ex) {
				logger
						.warn(
								"Template name resolver factory ["
										+ templateNameResolverFactoryClassName
										+ "] could not be created. Creating the default template name resolver factory ["
										+ DefaultTemplateNameResolverFactory.class
												.getName() + "]", ex);
				return createDefaultTemplateNameResolverFactory();
			}
		}
	}

	private static TemplateNameResolverFactory createDefaultTemplateNameResolverFactory() {
		return new DefaultTemplateNameResolverFactory();
	}
}
