package org.jvnet.hifaces.convert;

import java.text.DateFormat;
import java.text.ParseException;
import java.util.Date;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.ConverterException;

public abstract class AbstractDateConverter implements Converter {

	public Object getAsObject(FacesContext facesContext,
			UIComponent uiComponent, String value) {
		if (facesContext == null)
			throw new NullPointerException("facesContext");
		if (uiComponent == null)
			throw new NullPointerException("uiComponent");

		if (value != null) {
			value = value.trim();
			if (value.length() > 0) {
				DateFormat format = getDateFormat();
				try {
					final Date date = format.parse(value);
					return date;
				} catch (ParseException e) {
					throw new ConverterException(MessageUtils.getErrorMessage(
							facesContext, getConversionMessageId(),
							new Object[] { value, uiComponent.getId() }), e);
				}
			}
		}
		return null;
	}

	public String getAsString(FacesContext facesContext,
			UIComponent uiComponent, Object value) {
		if (facesContext == null)
			throw new NullPointerException("facesContext");
		if (uiComponent == null)
			throw new NullPointerException("uiComponent");

		if (value == null) {
			return "";
		}
		if (value instanceof String) {
			return (String) value;
		}

		final DateFormat format = getDateFormat();
		try {
			final Date date = (Date) value;
			return format.format(date);
		} catch (Exception e) {
			throw new ConverterException("Cannot convert value '" + value + "'");
		}
	}

	protected abstract DateFormat getDateFormat();

	protected abstract String getConversionMessageId();

}
