package org.jvnet.hifaces.event;

import java.lang.ref.Reference;
import java.lang.ref.WeakReference;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

public abstract class AbstractWeakListenerList {

  protected final List list = Collections.synchronizedList(new LinkedList());

  protected void add(Object listener) {
    synchronized (list) {
      final Reference listenerReference = new WeakReference(listener);
      list.add(listenerReference);
    }
  }

  protected void remove(Object listener) {
    synchronized (list) {
    	final Reference[] references = (Reference[]) list.toArray(new Reference[list.size()]);
    	for (int index = 0; index < references.length; index++) {
			final Reference reference = references[index];
	        final Object referent = reference.get();
	        if (listener == referent || referent == null) {
	        	list.remove(reference);
	          }
		}
    }
  }

  protected void clear() {
    synchronized (list) {
      list.clear();
    }
  }

  protected void fire(Object event) {
    synchronized (list) {
    	final Reference[] references = (Reference[]) list.toArray(new Reference[list.size()]);
    	for (int index = 0; index < references.length; index++) {
			final Reference reference = references[index];
	        final Object referent = reference.get();
	        if (referent == null) {
	          list.remove(referent);
	        }
	        else {
	          fire(referent, event);
	        }
		}
    }
  }
  
  protected abstract void fire(Object listener, Object event);
}
