package org.jvnet.hifaces.function;

import javax.faces.context.FacesContext;
import javax.faces.el.EvaluationException;
import javax.faces.el.PropertyNotFoundException;
import javax.faces.el.ValueBinding;

public class Property0<R> extends ValueBinding {

	private final Class<? extends R> type;

	private final Function0<R> getter;

	private final Function1<?, R> setter;

	public Property0(final Function0<R> getter, final Function1<?, R> setter) {
		this.type = getter.getType();
		this.getter = getter;
		this.setter = setter;
	}

	public Property0(final Function0<R> getter) {
		this.type = getter.getType();
		this.getter = getter;
		this.setter = null;
	}

	@Override
	public Class getType(FacesContext facesContext) throws EvaluationException,
			PropertyNotFoundException {
		return getType();
	}

	public Class<? extends R> getType() {
		return type;
	}

	@Override
	public Object getValue(FacesContext facesContext)
			throws EvaluationException, PropertyNotFoundException {
		try {
			return getter.invoke(facesContext);
		} catch (Exception ex) {
			throw new EvaluationException(ex);
		}
	}

	@Override
	public boolean isReadOnly(FacesContext facesContext)
			throws EvaluationException, PropertyNotFoundException {
		return setter == null;
	}

	@SuppressWarnings("unchecked")
	@Override
	public void setValue(FacesContext facesContext, Object value)
			throws EvaluationException, PropertyNotFoundException {
		if (setter == null) {
			throw new UnsupportedOperationException();
		} else {
			try {
				setter.invoke(facesContext, (R) value);
			} catch (Exception ex) {
				throw new EvaluationException(ex);
			}
		}
	}

}
