package org.jvnet.hifaces.text;

import java.io.Serializable;

import javax.faces.context.FacesContext;

/**
 * Textual value binding.
 * 
 * @author valikov
 */
public class Text extends AbstractSingularText implements Serializable {

	private static final long serialVersionUID = 1L;

	private final String messageId;

	private final String expressionString;

	private final Object[] arguments;

	/**
	 * Constructs a new textual value binding for the given message id.
	 * 
	 * @param messageId
	 *            message identifier.
	 */
	public Text(final String messageId) {
		this(messageId, (Object[]) null);
	}

	public Text(final String messageId, Object argument) {
		this(messageId, new Object[] { argument });
	}

	public Text(final String messageId, Object... arguments) {
		super();
		this.messageId = messageId;
		this.expressionString = "#{text['" + messageId + "']}";
		this.arguments = arguments;
	}

	@Override
	public String getExpressionString() {
		return expressionString;
	}

	@Override
	protected String getMessageId(FacesContext facesContext) {
		return messageId;
	}

	@Override
	protected Object[] getArguments(FacesContext facesContext) {
		return arguments;
	}
}
