package org.jvnet.hifaces.util;

import javax.faces.component.UIColumn;
import javax.faces.component.UIComponent;
import javax.faces.component.html.HtmlOutputText;
import javax.faces.el.ValueBinding;

import org.apache.myfaces.custom.sortheader.HtmlCommandSortHeader;

public class ColumnUtils {

	public static UIColumn createSortableColumn(final String messageId,
			final String columnName, final ValueBinding valueBinding) {
		final HtmlOutputText text = OutputUtils.createOutputText(messageId);
		final HtmlCommandSortHeader header = new HtmlCommandSortHeader();
		IdUtils.assignId("header", header);
		header.getChildren().add(text);
		header.setColumnName(columnName);
		header.setPropertyName(columnName);
		header.setArrow(true);
		final HtmlOutputText content = OutputUtils
				.createOutputText(valueBinding);
		return ColumnUtils.createColumn(header, content);
	}
  
  public static UIColumn createSortableColumn(final String messageId,
      final String columnName, final UIComponent content) {
    final HtmlOutputText text = OutputUtils.createOutputText(messageId);
    final HtmlCommandSortHeader header = new HtmlCommandSortHeader();
    IdUtils.assignId("header", header);
    header.getChildren().add(text);
    header.setColumnName(columnName);
    header.setPropertyName(columnName);
    header.setArrow(true);
    return ColumnUtils.createColumn(header, content);
  }

	public static UIColumn createColumn(final String messageId,
			final ValueBinding valueBinding) {
		final UIColumn column = ColumnUtils.createColumn(messageId, OutputUtils
				.createOutputText(valueBinding));
		return column;
	}

	/**
	 * Creates a column with text header and content.
	 * 
	 * @param messageId
	 *            message id to be displayedin the header.
	 * @param content
	 *            column content.
	 * @return Created column.
	 */
	public static UIColumn createColumn(final String messageId,
			final UIComponent content) {
		final UIColumn column = ColumnUtils.createColumn(OutputUtils
				.createOutputText(messageId), content);
		return column;
	}

	/**
	 * Creates a column with the given header and content.
	 * 
	 * @param header
	 *            header.
	 * @param content
	 *            content.
	 * @return Column with given header anmd content.
	 */
	@SuppressWarnings("unchecked")
	public static UIColumn createColumn(final UIComponent header,
			final UIComponent content) {
		final UIColumn column = createColumn();
		column.setHeader(header);
		column.getChildren().add(content);
		return column;
	}

	/**
	 * Creates a column.
	 * 
	 * @return Created column.
	 */
	public static UIColumn createColumn() {
		final UIColumn column = new UIColumn();
		IdUtils.assignId(column);
		return column;
	}

}
