package org.jvnet.hifaces.util;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Variable utilities.
 */
public class VariableUtils {

	/**
	 * Hidden constructor.
	 */
	private VariableUtils() {

	}

	/**
	 * Creates a value binding for the given variable.
	 * 
	 * @param variableName
	 *            name of the variable.
	 * @return Value binding for the variable name.
	 */
	public static ValueBinding createValueBinding(String variableName) {
		final FacesContext facesContext = FacesContext.getCurrentInstance();
		if (facesContext == null) {
			throw new IllegalStateException("No Faces context found.");
		} else {
			return facesContext.getApplication().createValueBinding(
					"#{" + variableName + "}");
		}
	}

	/**
	 * Creates value bindings for variable names.
	 * 
	 * @param variableNames
	 *            variable names.
	 * @return Value bindings for variable names.
	 */
	public static ValueBinding[] createValueBinding(String... variableNames) {
		final ValueBinding[] valueBindings = new ValueBinding[variableNames.length];
		for (int index = 0; index < variableNames.length; index++) {
			final String variableName = variableNames[index];
			valueBindings[index] = createValueBinding(variableName);
		}
		return valueBindings;
	}

	public static ValueBinding createVariableExpression(Class variableType,
			String variableName, String expression) {
		final FacesContext facesContext = FacesContext.getCurrentInstance();
		if (facesContext == null) {
			throw new IllegalStateException("No Faces context found.");
		} else {
			final String exp = "#{" + variableName + "." + expression + "}";
			return facesContext.getApplication().createValueBinding(exp);
		}
	}
}
